/**
 * @file
 * JS handler for reading progress bar.
 */
((once) => {
  function isElementVisible(el) {
    const style = window.getComputedStyle(el);
    return style.display !== 'none';
  }
  function initProgressBar(progressBar) {
    const autoHideDelay = progressBar.dataset.hideDelay || 0;
    const minimumDocumentScreenRatio = progressBar.dataset.minRatio || 2;
    let isVisible = isElementVisible(progressBar);
    function setupProgressBar() {
      /* Set the max scrollable area */
      const winHeight = window.innerHeight;
      const docHeight = document.documentElement.scrollHeight;
      const max = docHeight - winHeight;
      progressBar.setAttribute('max', max);
      if (docHeight / winHeight > minimumDocumentScreenRatio) {
        progressBar.style.display = '';
        isVisible = true;
      } else {
        progressBar.style.display = 'none';
        isVisible = false;
      }
    }
    function updateProgressBarValue() {
      const value = window.scrollY;
      progressBar.setAttribute('value', value);
    }
    // Initial setup.
    setupProgressBar();
    // Refresh setup when the page is fully loaded.
    window.addEventListener('load', setupProgressBar);
    // Refresh setup when the viewport is resized.
    window.addEventListener('resize', setupProgressBar);
    let autoHideTimer = null;
    document.addEventListener('scroll', () => {
      // Update progress bar if visible only.
      if (isVisible) {
        updateProgressBarValue();
        if (progressBar.classList.contains('hidden')) {
          progressBar.classList.remove('hidden');
        }
        if (autoHideDelay > 0) {
          if (autoHideTimer) {
            clearTimeout(autoHideTimer);
          }
          autoHideTimer = setTimeout(() => {
            progressBar.classList.add('hidden');
          }, autoHideDelay);
        }
      }
    });
  }

  Drupal.behaviors.reading_progress_bar = {
    attach(context) {
      const progressBars = once('reading_progress_bar', 'progress', context);
      progressBars.forEach((progressBar) => {
        initProgressBar(progressBar);
      });
    },
  };
})(once);
